@@ -1,47 +1,48 @@
-################ import ################
-import os
-from os import system
-import sys
-import webbrowser
-import logging
-import pickle
+# ################ import ################
+# import os
+# from os import system
+# import sys
+# import webbrowser
+# import logging
+# import pickle
+#
+# import pyautogui
+# import pyodbc
+# import smtplib
+# import string
+# import time
+# import tempfile
+#
+# if sys.platform != "win32":
+#     import fcntl
+#
+# from urllib.request import urlopen
+# from logging.handlers import RotatingFileHandler
+# from string import Template
+#
+# # ========================================================================================================#
+# from selenium import webdriver
+# from selenium.webdriver.chrome.options import Options
+# from selenium.webdriver.support.ui import WebDriverWait
+# from selenium.webdriver.support import expected_conditions as EC
+# from selenium.webdriver.common.by import By
+# from selenium.webdriver.common.action_chains import ActionChains
+# from selenium.webdriver.common.keys import Keys
+# # ========================================================================================================#
+# from sys import platform as _platform
+# from pandas.io.clipboard import clipboard_get, clipboard_set
+# from pynput.keyboard import Key, Controller
+# import pynput
+#
+# # from settings import *
+# from fico21softlibs.settings import *
+#
+# if _platform == 'win32' or _platform == 'win64':
+#     import win32api
+#     import win32con
+# ################ import ################
 
-import pyautogui
-import pyodbc
-import smtplib
-import string
-import time
-import tempfile
-
-if sys.platform != "win32":
-    import fcntl
-
-from urllib.request import urlopen
-from logging.handlers import RotatingFileHandler
-from string import Template
-
-# ========================================================================================================#
-from selenium import webdriver
-from selenium.webdriver.chrome.options import Options
-from selenium.webdriver.support.ui import WebDriverWait
-from selenium.webdriver.support import expected_conditions as EC
-from selenium.webdriver.common.by import By
-from selenium.webdriver.common.action_chains import ActionChains
-from selenium.webdriver.common.keys import Keys
-# ========================================================================================================#
-from sys import platform as _platform
-from pandas.io.clipboard import clipboard_get, clipboard_set
-from pynput.keyboard import Key, Controller
-import pynput
-
-# from settings import *
-from fico21softlibs.settings import *
-
-if _platform == 'win32' or _platform == 'win64':
-    import win32api
-    import win32con
-
-################ import ################
+from fico21softlibs.import_all import *
 
 class SingleInstanceException(BaseException):
     pass
@@ -362,45 +363,42 @@ class CommonLib:
     @staticmethod
     def wd_send_keys(wd, keys):
         ActionChains(wd).send_keys(keys).perform()
+
+    @staticmethod
+    def wd_paste(wd):
+        data = CommonLib.get_clipboard_data()
+        CommonLib.wd_send_keys(wd, str(data))
     # ========================================================================================================#
     '''
     It's needed test 
     '''
-    @staticmethod
-    def wd_send_key_ctrl(wd, key):
-        ActionChains(wd).key_down(Keys.COMMAND).send_keys(key).perform()
-        # ActionChains(wd) \
-        #     .key_down(Keys.COMMAND) \
-        #     .key_down(key) \
-        #     .key_up(key) \
-        #     .key_up(Keys.COMMAND) \
-        #     .perform()
-
-    @staticmethod
-    def send_keys(keys):
-        keyboard = Controller()
-        keyboard.type(keys)
+    # @staticmethod
+    # def wd_send_key_ctrl(wd, key):
+    #     # firefox only
+    #     # ActionChains(wd).key_down(Keys.COMMAND).send_keys(key).perform()
+    #     data = CommonLib.get_clipboard_data()
+    #     CommonLib.wd_send_keys(wd, str(data))
     # ========================================================================================================#
     @staticmethod
     def get_clipboard_data():
-        if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
-            win32clipboard.OpenClipboard()
-            data = win32clipboard.GetClipboardData()
-            win32clipboard.CloseClipboard()
-            return data
-        else:
-            return clipboard_get()
+        # if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
+        #     win32clipboard.OpenClipboard()
+        #     data = win32clipboard.GetClipboardData()
+        #     win32clipboard.CloseClipboard()
+        #     return data
+        # else:
+        return clipboard_get()
 
     @staticmethod
     def set_clipboard_data(data):
-        if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
-            win32clipboard.OpenClipboard()
-            win32clipboard.EmptyClipboard()
-            win32clipboard.SetClipboardData(win32clipboard.CF_UNICODETEXT, data)
-            win32clipboard.CloseClipboard()
-            return 'OK'
-        else:
-            return clipboard_set(data)
+        # if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
+        #     win32clipboard.OpenClipboard()
+        #     win32clipboard.EmptyClipboard()
+        #     win32clipboard.SetClipboardData(win32clipboard.CF_UNICODETEXT, data)
+        #     win32clipboard.CloseClipboard()
+        # else:
+        clipboard_set(data)
+        return 'OK'
     # ========================================================================================================#
     # Windows only
     # ========================================================================================================#
@@ -410,7 +408,7 @@ class CommonLib:
             send_keys("{VK_LCONTROL down}"
                       "a"
                       "{VK_LCONTROL up}")
-            set_clipboard_data(data)
+            CommonLib.set_clipboard_data(data)
             send_keys("{VK_LCONTROL down}"
                       "v"
                       "{VK_LCONTROL up}")
@@ -421,20 +419,20 @@ class CommonLib:
     '''
     It's needed test 
     '''
-    @staticmethod
-    def send_key_ctrl(key):
-        if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
-            send_keys("{VK_LCONTROL down}"
-                      "a"
-                      "{VK_LCONTROL up}")
-            set_clipboard_data(key)
-            send_keys("{VK_LCONTROL down}"
-                      "v"
-                      "{VK_LCONTROL up}")
-        else:
-            pass
+    # @staticmethod
+    # def send_key_ctrl(key):
+    #     if CommonLib.os() == WINDOWS32 or CommonLib.os() == WINDOWS64:
+    #         send_keys("{VK_LCONTROL down}"
+    #                   "a"
+    #                   "{VK_LCONTROL up}")
+    #         set_clipboard_data(key)
+    #         send_keys("{VK_LCONTROL down}"
+    #                   "v"
+    #                   "{VK_LCONTROL up}")
+    #     else:
+    #         pass
     # ========================================================================================================#
-    @staticmethod
+    # @staticmethod
     def scroll(clicks=0, delta_x=0, delta_y=0, delay_between_ticks=0):
         """
         Source: https://docs.microsoft.com/en-gb/windows/win32/api/winuser/nf-winuser-mouse_event?redirectedfrom=MSDN
@@ -468,18 +466,16 @@ class CommonLib:
         for _ in range(abs(clicks)):
             win32api.mouse_event(win32con.MOUSEEVENTF_WHEEL, delta_x, delta_y, increment, 0)
             time.sleep(delay_between_ticks)
-
+    # ========================================================================================================#
 
 # test only
 if __name__ == '__main__':
-    # wd = CommonLib.get_webdriver()
-    # wd.get('http:\\www.naver.com')
-    # CommonLib.wd_send_keys(wd, 'dsdfsgshgjchkjhvk')
-    #
-    # CommonLib.send_keys(' send_keys')
-    # time.sleep(2)
-    # CommonLib.set_clipboard_data('paste by python')
-    # CommonLib.wd_send_key_ctrl(wd,'a')
-    # CommonLib.wd_send_key_ctrl(wd,'v')
+    wd = CommonLib.get_webdriver()
+    wd.get('http:\\www.naver.com')
+    time.sleep(1)
+
+    CommonLib.set_clipboard_data('paste by python')
+    CommonLib.wd_paste(wd)
+
 
     pass
\ No newline at end of file
