@@ -13,9 +13,6 @@ import string
 import time
 import tempfile
 
-if sys.platform != "win32":
-    import fcntl
-
 from urllib.request import urlopen
 from logging.handlers import RotatingFileHandler
 from string import Template
@@ -29,7 +26,6 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.keys import Keys
 # ========================================================================================================#
-from sys import platform as _platform
 from pandas.io.clipboard import clipboard_get, clipboard_set
 from pynput.keyboard import Key, Controller
 import pynput
@@ -37,8 +33,10 @@ import pynput
 # from settings import *
 from fico21softlibs.settings import *
 
+from sys import platform as _platform
 if _platform == 'win32' or _platform == 'win64':
+    import fcntl
     import win32api
     import win32con
-
+    from pywinauto.keyboard import send_keys
 ################ import ################
